import string

from .api import hexadecimal, hsl, rgb, cmyk
from .str import string as stringcolor

def autodetect(args:str) -> str:

    '''
    Using AutoDetect:
    
    Alert It only works if you are connected to the internet
    >>>
    >>> import hexacolors
    >>> hexacolors.autodetect('Blue') #Identify string
    >>> hexacolors.autodetect('#fff000') #Identify Hexadecimal
    >>> hexacolors.autodetect('255,255,255') #Identify RGB
    >>> hexacolors.autodetect('423,522,4,244') #Identify CMYK
    >>> hexacolors.autodetect('255,75%,64%') #Identify HSL
    '''

    if args[0] == '#':hexadecimal(args)
    elif args.count('%') > 0:hsl(args)
    elif args.count(',') == 2:rgb(args)
    elif args.count(',') == 3:cmyk(args)
    elif args[0] in list(string.digits):hexadecimal(args)
    elif args[0] in list(string.ascii_letters):
        try:stringcolor(args)
        except:hexadecimal(args)
    else:print('ERROR: Not indentify the type')


from .colors.gray import *
from .colors.blue import *
from .colors.cyan import *
from .colors.brown import *
from .colors.purple import *
from .colors.pink import *
from .colors.green import *
from .colors.red import *
from .colors.orange import *
from .colors.yellow import *
from .colors.ligthcolors import *

def stringColor(cor:str) -> str:

    '''
    Using StringColor:

    >>> import hexacolors
    >>> hexacolors.stringColor('Blue')
    >>> print(hexacolors.listall) #List all colors availables
    '''

    if cor.lower().replace(' ','') == 'black':return black()
    elif cor.lower().replace(' ','') == 'gray1':return grey11()
    elif cor.lower().replace(' ','') == 'gray2':return grey21()
    elif cor.lower().replace(' ','') == 'gray3':return grey31()
    elif cor.lower().replace(' ','') == 'dimgray':return dimgray()
    elif cor.lower().replace(' ','') == 'gray':return gray()
    elif cor.lower().replace(' ','') == 'darkgray':return darkgray()
    elif cor.lower().replace(' ','') == 'silver':return silver()
    elif cor.lower().replace(' ','') == 'ligthgrey':return ligthgrey()
    elif cor.lower().replace(' ','') == 'gainsboro':return gainsboro()
    elif cor.lower().replace(' ','') == 'slateblue':return slateblue()
    elif cor.lower().replace(' ','') == 'slateblue1':return slateblue1()
    elif cor.lower().replace(' ','') == 'slateblue2':return slateblue3()
    elif cor.lower().replace(' ','') == 'darkslateblue':return darkslateblue()
    elif cor.lower().replace(' ','') == 'midnightblue':return midnightblue()
    elif cor.lower().replace(' ','') == 'navy':return navy()
    elif cor.lower().replace(' ','') == 'darkblue':return darkblue()
    elif cor.lower().replace(' ','') == 'mediumblue':return mediumblue()
    elif cor.lower().replace(' ','') == 'blue':return blue()
    elif cor.lower().replace(' ','') == 'cornflowerblue':return cornflowerblue()
    elif cor.lower().replace(' ','') == 'royalblue':return royalblue()
    elif cor.lower().replace(' ','') == 'dodgerblue':return dodgerblue()
    elif cor.lower().replace(' ','') == 'deepskyblue':return deepskyblue()
    elif cor.lower().replace(' ','') == 'lightskyblue':return lightskyblue()
    elif cor.lower().replace(' ','') == 'skyblue':return skyblue()
    elif cor.lower().replace(' ','') == 'lightblue':return lightblue()
    elif cor.lower().replace(' ','') == 'steelblue':return steelblue()
    elif cor.lower().replace(' ','') == 'lightsteelblue':return lightsteelblue()
    elif cor.lower().replace(' ','') == 'slategray':return slategray()
    elif cor.lower().replace(' ','') == 'lightslategray':return lightslategray()
    elif cor.lower().replace(' ','') == 'cyan':return cyan()
    elif cor.lower().replace(' ','') == 'darkturquoise':return darkturquoise()
    elif cor.lower().replace(' ','') == 'turquoise':return turquoise()
    elif cor.lower().replace(' ','') == 'mediumturquoise':return mediumturquoise()
    elif cor.lower().replace(' ','') == 'lightseagreen':return lightseagreen()
    elif cor.lower().replace(' ','') == 'darkcyan':return darkcyan()
    elif cor.lower().replace(' ','') == 'teal':return teal()
    elif cor.lower().replace(' ','') == 'aquamarine':return aquamarine()
    elif cor.lower().replace(' ','') == 'mediumaquamarine':return mediumaquamarine()
    elif cor.lower().replace(' ','') == 'cadetblue':return cadetblue()
    elif cor.lower().replace(' ','') == 'darkkhaki':return darkkhaki()
    elif cor.lower().replace(' ','') == 'goldenrod':return goldenrod()
    elif cor.lower().replace(' ','') == 'darkgoldenrod':return darkgoldenrod()
    elif cor.lower().replace(' ','') == 'saddlebrown':return saddlebrown()
    elif cor.lower().replace(' ','') == 'sienna':return sienna()
    elif cor.lower().replace(' ','') == 'rosybrown':return rosybrown()
    elif cor.lower().replace(' ','') == 'peru':return peru()
    elif cor.lower().replace(' ','') == 'chocolate':return chocolate()
    elif cor.lower().replace(' ','') == 'sandybrown':return sandybrown()
    elif cor.lower().replace(' ','') == 'navajowhite':return navajowhite()
    elif cor.lower().replace(' ','') == 'wheat':return wheat()
    elif cor.lower().replace(' ','') == 'burlywood':return burlywood()
    elif cor.lower().replace(' ','') == 'tan':return tan()
    elif cor.lower().replace(' ','') == 'mediumslateBllue':return mediumslateBllue()
    elif cor.lower().replace(' ','') == 'mediumpurple':return mediumpurple()
    elif cor.lower().replace(' ','') == 'blueviolet':return blueviolet()
    elif cor.lower().replace(' ','') == 'indigo':return indigo()
    elif cor.lower().replace(' ','') == 'darkviolet':return darkviolet()
    elif cor.lower().replace(' ','') == 'darkorchid':return darkorchid()
    elif cor.lower().replace(' ','') == 'mediumorchid':return mediumorchid()
    elif cor.lower().replace(' ','') == 'purple':return purple()
    elif cor.lower().replace(' ','') == 'darkmagenta':return darkmagenta()
    elif cor.lower().replace(' ','') == 'magenta':return magenta()
    elif cor.lower().replace(' ','') == 'violet':return violet()
    elif cor.lower().replace(' ','') == 'orchid':return orchid()
    elif cor.lower().replace(' ','') == 'plum':return plum()
    elif cor.lower().replace(' ','') == 'mediumvioletred':return mediumvioletred()
    elif cor.lower().replace(' ','') == 'deeppink':return deeppink()
    elif cor.lower().replace(' ','') == 'hotpink':return hotpink()
    elif cor.lower().replace(' ','') == 'palevioletred':return palevioletred()
    elif cor.lower().replace(' ','') == 'lightpink':return lightpink()
    elif cor.lower().replace(' ','') == 'pink':return pink()
    elif cor.lower().replace(' ','') == 'lightcoral':return lightcoral()
    elif cor.lower().replace(' ','') == 'indianred':return indianred()
    elif cor.lower().replace(' ','') == 'crimson':return crimson()
    elif cor.lower().replace(' ','') == 'darkslategreen':return darkslategreen()
    elif cor.lower().replace(' ','') == 'mediumspringgreen':return mediumspringgreen()
    elif cor.lower().replace(' ','') == 'springgreen':return springgreen()
    elif cor.lower().replace(' ','') == 'palegreen':return palegreen()
    elif cor.lower().replace(' ','') == 'lightgreen':return lightgreen()
    elif cor.lower().replace(' ','') == 'darkseagreen':return darkseagreen()
    elif cor.lower().replace(' ','') == 'mediumseagreen':return mediumseagreen()
    elif cor.lower().replace(' ','') == 'seagreen':return seagreen()
    elif cor.lower().replace(' ','') == 'darkgreen':return darkgreen()
    elif cor.lower().replace(' ','') == 'green':return green()
    elif cor.lower().replace(' ','') == 'forestgreen':return forestgreen()
    elif cor.lower().replace(' ','') == 'limegreen':return limegreen()
    elif cor.lower().replace(' ','') == 'lime':return lime()
    elif cor.lower().replace(' ','') == 'lawngreen':return lawngreen()
    elif cor.lower().replace(' ','') == 'chartreuse':return chartreuse()
    elif cor.lower().replace(' ','') == 'greenyellow':return greenyellow()
    elif cor.lower().replace(' ','') == 'yellowgreen':return yellowgreen()
    elif cor.lower().replace(' ','') == 'olivedrab':return olivedrab()
    elif cor.lower().replace(' ','') == 'darkolivegreen':return darkolivegreen()
    elif cor.lower().replace(' ','') == 'olive':return olive()
    elif cor.lower().replace(' ','') == 'maroon':return maroon()
    elif cor.lower().replace(' ','') == 'darkred':return darkred()
    elif cor.lower().replace(' ','') == 'firebrick':return firebrick()
    elif cor.lower().replace(' ','') == 'brown':return brown() 
    elif cor.lower().replace(' ','') == 'salmon':return salmon()
    elif cor.lower().replace(' ','') == 'darksalmon':return darksalmon()
    elif cor.lower().replace(' ','') == 'lightsalmon':return lightsalmon()
    elif cor.lower().replace(' ','') == 'coral':return coral()
    elif cor.lower().replace(' ','') == 'tomato':return tomato()
    elif cor.lower().replace(' ','') == 'red':return red()
    elif cor.lower().replace(' ','') == 'orangered':return orangered()
    elif cor.lower().replace(' ','') == 'darkorange':return darkorange()
    elif cor.lower().replace(' ','') == 'orange':return orange()
    elif cor.lower().replace(' ','') == 'gold':return gold()
    elif cor.lower().replace(' ','') == 'yellow':return yellow()
    elif cor.lower().replace(' ','') == 'khaki':return khaki()
    elif cor.lower().replace(' ','') == 'white':return white()
    elif cor.lower().replace(' ','') == 'aliceblue':return aliceblue()
    elif cor.lower().replace(' ','') == 'ghostwhite':return ghostwhite()
    elif cor.lower().replace(' ','') == 'snow':return snow()
    elif cor.lower().replace(' ','') == 'seashell':return seashell()
    elif cor.lower().replace(' ','') == 'floralwhite':return floralwhite()
    elif cor.lower().replace(' ','') == 'whitesmoke':return whitesmoke()
    elif cor.lower().replace(' ','') == 'beige':return beige()
    elif cor.lower().replace(' ','') == 'oldlace':return oldlace()
    elif cor.lower().replace(' ','') == 'ivory':return ivory()
    elif cor.lower().replace(' ','') == 'linen':return linen()
    elif cor.lower().replace(' ','') == 'cornsilk':return cornsilk()
    elif cor.lower().replace(' ','') == 'antiquewhite':return antiquewhite()
    elif cor.lower().replace(' ','') == 'blanchedalmond':return blanchedalmond()
    elif cor.lower().replace(' ','') == 'bisque':return bisque()
    elif cor.lower().replace(' ','') == 'lightyellow':return lightyellow()
    elif cor.lower().replace(' ','') == 'lemonchiffon':return lemonchiffon()
    elif cor.lower().replace(' ','') == 'lightgoldenrodyellow':return lightgoldenrodyellow()
    elif cor.lower().replace(' ','') == 'papayawhip':return papayawhip()
    elif cor.lower().replace(' ','') == 'peachpuff':return peachpuff()
    elif cor.lower().replace(' ','') == 'moccasin':return moccasin()
    elif cor.lower().replace(' ','') == 'palegoldenrod':return palegoldenrod()
    elif cor.lower().replace(' ','') == 'mistyrose':return mistyrose()
    elif cor.lower().replace(' ','') == 'lavenderblush':return lavenderblush()
    elif cor.lower().replace(' ','') == 'lavender':return lavender()
    elif cor.lower().replace(' ','') == 'thistle':return thistle()
    elif cor.lower().replace(' ','') == 'azure':return azure()
    elif cor.lower().replace(' ','') == 'lightcyan':return lightcyan()
    elif cor.lower().replace(' ','') == 'powderblue':return powderblue()
    elif cor.lower().replace(' ','') == 'paleturquoise':return paleturquoise()
    elif cor.lower().replace(' ','') == 'honeydew':return honeydew()
    elif cor.lower().replace(' ','') == 'mintcream':return mintcream()


import requests

def hexadecimaloff(hexa:str) -> str:

    '''
    Using HexaColor:

    >>> import hexacolors
    >>> hexacolors.hexadecimaloff('#0000FF') #Convert Hexadecimal Color for Python understand
    '''

    if hexa[0] == '#':hexa = hexa[1::]

    return int(f"0x{hexa}",16)

def rgboff(r:int,g:int,b:int) -> int:

    '''
    Using rgb:

    >>> import hexacolors
    >>> hexacolors.rgboff(255,255,255)
    '''

    return int('0x{:X}{:X}{:X}'.format(r, g, b),16)

def cmykoff(c:int,m:int,y:int,k:int) -> str:

    '''
    Using cmyk:

    >>> import hexacolors
    >>> hexacolors.cmykoff('423,522,4,244')
    '''

    return int('0x{:X}{:X}{:X}{:X}'.format(c, m, y, k),16)


def black():return 0x00000
def grey11():return 0x1C1C1C
def grey21():return 0x363636
def grey31():return 0x4F4F4F
def dimgray():return 0x696969
def gray():return 0x808080
def darkgray():return 0xA9A9A9
def silver():return 0xC0C0C0
def ligthgrey():return 0xD3D3D3
def gainsboro():return 0xDCDCDC


def cyan():return 0x00FFFF
def darkturquoise():return 0x00CED1
def turquoise():return 0x40E0D0
def mediumturquoise():return 0x48D1CC
def lightseagreen():return 0x20B2AA
def darkcyan():return 0x008B8B
def teal():return 0x008080
def aquamarine():return 0x7FFFD4
def mediumaquamarine():return 0x66CDAA
def cadetblue():return 0x5F9EA0


import requests

def hexadecimal(hexa:str) -> str:

    '''
    Using HexaColor:

    >>> import hexacolors
    >>> hexacolors.hexadecimal('#0000FF') #Convert Hexadecimal Color for Python understand
    '''

    if hexa[0] == '#':hexa = hexa[1::]
    
    p = requests.get(f'https://www.thecolorapi.com/id?hex={hexa}')

    return int(f"0x{p.json()['hex']['clean']}",16)
    

def rgb(rgb) -> int:

    '''
    Using rgb:

    >>> import hexacolors
    >>> hexacolors.rgb('255,255,255')
    '''
    
    p = requests.get(f'https://www.thecolorapi.com/id?rgb={rgb}')
    
    return int(f"0x{p.json()['hex']['clean']}",16)

def cmyk(c:int,m:int,y:int,k:int) -> str:

    '''
    Using cmyk:

    >>> import hexacolors
    >>> hexacolors.cmyk('423,522,4,244')
    '''

    p = requests.get(f'https://www.thecolorapi.com/id?cmyk={c},{m},{y},{k}')

    return int(f"0x{p.json()['hex']['clean']}",16)

def hsl(hsl:str) -> str:

    '''
    Using hsl:

    >>> import hexacolors
    >>> hexacolors.hsl('423,60%,70%')
    '''

    p = requests.get(f'https://www.thecolorapi.com/id?hsl={hsl}')

    return int(f"0x{p.json()['hex']['clean']}",16)